Hospital Outpatient Activity - NHS England Digital
Description: We’re the national information and technology partner to the health and social care system using digital technology to transform the NHS and social care

Skip to main content
Series / Collection

# Hospital Outpatient Activity

National statistics, Accredited official statistics

Frequency:
  Yearly

Geographic Coverage:
  England

Geographical Granularity:
  Strategic Health Authorities, Hospital Trusts, Independent Sector Health Care Providers, Regions, NHS Trusts, Country

## Summary

Hospital Outpatient Activity

## Latest statistics

- ### Hospital Outpatient Activity 2024-25

  This publication reports on Outpatient activity in England for the financial year 2024-25.

  Published: 25 September 2025

## Past publications

- ### Hospital Outpatient Activity 2023-24

  This publication reports on Outpatient activity in England for the financial year 2023-24.

  26 September 2024

- ### Hospital Outpatient Activity 2022-23

  This publication reports on Outpatient activity in England for the financial year 2022-23.

  21 September 2023

- ### Hospital Outpatient Activity 2021-22

  Please note, the data in the Provider Level Analysis file were updated on 04/11/2022 due to an issue identified with some of the counts in tables 1 and...

  29 September 2022

- ### Hospital Outpatient Activity 2020-21

  This is a report on outpatient activity in English NHS hospitals and English NHS-commissioned activity in the independent sector. This annual publication...

  23 September 2021

- ### Hospital Outpatient Activity 2019-20

  This is a report on outpatient activity in English NHS hospitals and English NHS-commissioned activity in the independent sector. This annual publication...

  8 October 2020

- ### Hospital Outpatient Activity 2018-19

  This is a report on outpatient activity in English NHS hospitals and English NHS-commissioned activity in the independent sector. This annual publication...

  10 October 2019

- ### Hospital Outpatient Activity, 2017-18

  This is a report on outpatient activity in English NHS hospitals and English NHS-commissioned activity in the independent sector. This annual publication...

  11 October 2018

- ### Hospital Outpatient Activity, 2016-17

  28 November 2017

- ### Hospital Outpatient Activity, 2015-16

  1 December 2016

- ### Hospital Outpatient Activity - 2014-15

  18 December 2015

- ### Hospital Outpatient Activity - 2013-14

  28 January 2015

- ### Hospital Outpatient Activity - 2012-13

  12 December 2013

- ### Hospital Outpatient Activity - 2011-12

  19 December 2012

- ### Hospital Outpatient Activity - 2010-11

  20 December 2011

- ### Hospital Outpatient Activity - 2009-10

  14 December 2010

- ### Hospital Outpatient Activity - 2008-09

  15 December 2009

- ### Hospital Outpatient Activity - 2007-08

  27 February 2009

- ### Hospital Outpatient Activity - 2006-07

  16 April 2008

- ### Hospital Outpatient Activity - 2005-06

  17 May 2007

- ### Hospital Outpatient Activity - 2003-04

  1 May 2007

- ### Hospital Outpatient Activity - 2004-05

  1 May 2007

- ### Outpatient Data Quality Report

  15 December 2006